"""
CVE Extractor - Extract, filter, and analyze CVE data.

A tool for mining CVE data from the official CVE List with
filtering by CWE type, keywords, and GitHub patch information.
"""

from . import core

__version__ = "0.1.0"
__all__ = ["core", "__version__"]
